FL.objects.FontLab.FakeLab
==========================

.. currentmodule:: FL.objects.FontLab

.. autoclass:: FakeLab
   :members:
   :show-inheritance:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~FakeLab.Add
      ~FakeLab.BeginProgress
      ~FakeLab.CallCommand
      ~FakeLab.Close
      ~FakeLab.EditGlyph
      ~FakeLab.EndProgress
      ~FakeLab.ForSelected
      ~FakeLab.GenerateFont
      ~FakeLab.GetCanvas
      ~FakeLab.GetConvert
      ~FakeLab.GetFileName
      ~FakeLab.GetPathName
      ~FakeLab.GlyphToScreen
      ~FakeLab.HitContour
      ~FakeLab.LoadNamFile
      ~FakeLab.Lock
      ~FakeLab.Message
      ~FakeLab.Open
      ~FakeLab.OpenFont
      ~FakeLab.Random
      ~FakeLab.Save
      ~FakeLab.ScreenToGlyph
      ~FakeLab.Select
      ~FakeLab.Selected
      ~FakeLab.SetFontWindow
      ~FakeLab.SetUndo
      ~FakeLab.TickProgress
      ~FakeLab.TransformGlyph
      ~FakeLab.Unselect
      ~FakeLab.UpdateFont
      ~FakeLab.UpdateGlyph
      ~FakeLab.UpdateRect
      ~FakeLab.__init__
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~FakeLab.ifontslist
      ~FakeLab.iglyph
      ~FakeLab.delta
      ~FakeLab.scale
      ~FakeLab.preview
      ~FakeLab.count
      ~FakeLab.count_selected
      ~FakeLab.filename
      ~FakeLab.font
      ~FakeLab.glyph
      ~FakeLab.ifont
      ~FakeLab.iobject
      ~FakeLab.layer
      ~FakeLab.mainwindow
      ~FakeLab.path
      ~FakeLab.productnumber
      ~FakeLab.serialnumber
      ~FakeLab.tobject
      ~FakeLab.username
      ~FakeLab.version
      ~FakeLab.window
   
   